/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ste.tmc.allgemein;

/**
 * Die möglichen RDS-Ereignisse.
 * 
 * Erstellt auf Basis der SWE RDS/TMC von: Dambach Werke GmbH, Stefan Sans
 * 
 * @since 07/2016: Adaptiert für TMC-Meldungen durch: BitCtrl Systems GmbH
 * @author BitCtrl Systems GmbH, Gieseler
 */
public enum RDSEreignis {

	/** . */
	KEINE_AUSSAGE(1, "keine Aussage"),

	/** . */
	DICHTER_VERKEHR(2, "dichter Verkehr"),

	/** . */
	STOCKENDER_VERKEHR(3, "stockender Verkehr"),

	/** . */
	STAU(4, "Stau");

	/**
	 * Numerische Darstellung des Ereignisses.
	 */
	public final int id;

	/**
	 * Text-Darstellung des Ereignisses.
	 */
	public final String text;

	@Override
	public String toString() {
		return text;
	}

	/**
	 * Gibt das zur übergebenen Ereignis-Id gehörende RDSEreignis zurück.
	 * 
	 * @param id
	 *            Ereignis-Id
	 * @return das zur übergebenen Ereignis-Id gehörende RDSEreignis oder null,
	 *         falls es zur Id kein RDSEreignis gibt
	 */
	public static RDSEreignis get(final int id) {
		for (RDSEreignis ereignis : values()) {
			if (ereignis.id == id) {
				return ereignis;
			}
		}
		return null;
	}

	/**
	 * Privater Konstruktor.
	 * 
	 * @param id
	 *            ID
	 * @param text
	 *            Text
	 */
	RDSEreignis(final int id, final String text) {
		this.id = id;
		this.text = text;
	}

}
