/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ste.tmc.meldungserstellung;

/**
 * Location-Methode zum Erstellen von Meldungen
 * 
 * 
 * Erstellt auf Basis der SWE RDS/TMC von: Dambach Werke GmbH, Stefan Sans
 * 
 * @since 07/2016: Adaptiert für TMC-Meldungen durch: BitCtrl Systems GmbH
 * @author BitCtrl Systems GmbH, Gieseler
 */
public enum LocationMethode {
	LISTE(0, "erste Feldposition ist primäre Location und letzte Feldposition ist sekundäre Location"), EXTEND(1,
			"Primäre Location und Extent sind gültig");

	/**
	 * Numerische Darstellung der Location-Methode.
	 */
	public final int id;

	/**
	 * Text-Darstellung der Location-Methode.
	 */
	public final String text;

	@Override
	public String toString() {
		return text;
	}

	/**
	 * .
	 * 
	 * @param id
	 *            der LocationMethode
	 * @return die zur übergebenen Id gehörende LocationMethode oder null, falls
	 *         es zur Id keine LocationMethode gibt
	 */
	public static LocationMethode get(int id) {
		for (LocationMethode methode : values()) {
			if (methode.id == id) {
				return methode;
			}
		}
		return null;
	}

	/**
	 * Privater Konstruktor.
	 * 
	 * @param id
	 *            ID
	 * @param text
	 *            Text
	 */
	private LocationMethode(int id, String text) {
		this.id = id;
		this.text = text;
	}

}
