/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ste.tmc.meldungserstellung;

import de.bsvrz.dav.daf.main.config.ConfigurationArea;

/**
 * Schnittstelle für Datenelemente, die für die Erstellung unf Verwaltung von
 * Meldungen global sind. Implementierung z. B. über Kommandozeilenargumente
 * 
 * 
 * Erstellt auf Basis der SWE RDS/TMC von: Dambach Werke GmbH, Stefan Sans
 * 
 * @since 07/2016: Adaptiert für TMC-Meldungen durch: BitCtrl Systems GmbH
 * @author BitCtrl Systems GmbH, Gieseler
 */
public interface MeldungenGlobal {
	/**
	 * @return den Konfigurationsbereich, in dem dynamische Meldungsobjekte
	 *         abgelegt werden
	 */
	public ConfigurationArea getKonfigurationsbereich();

	/**
	 * @return die LocationMethode, nach der Meldungsdatensätze kodiert werden
	 */
	public LocationMethode getLocationMethode();

	/**
	 * @return die Methode, nach der beim Programmstart aktuelle Zustände
	 *         publiziert werden
	 */
	public PublikationInitial getPublikationInitial();

	/**
	 * @return die (Text-) Id der Organisationseinheit, die einer generierten
	 *         Meldung zugeordnet sein soll - i. d. R. LMS
	 */
	public String getIdOrganisation();

	/**
	 * @return die (numerische) Id der Organisationseinheit, die einer
	 *         generierten Meldung zugeordnet sein soll - i. d. R. LMS
	 */
	public String getIdNummer();

	/**
	 * @return Zeitspanne in min., wielange eine Meldung gültig (nicht
	 *         abgelaufen) sein soll, nachdem sie aktualisiert wurde
	 */
	public int getAblaufOffset();

}
