/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ste.tmc.verkehrsanalyse;

import de.bsvrz.ste.tmc.konfiguration.MessQuerschnitt;

/**
 * Modelliert einen lokalen Störfall in Bezug auf einen Messquerschnitt.
 * 
 * 
 * Erstellt auf Basis der SWE RDS/TMC von: Dambach Werke GmbH, Stefan
 * Sans
 *  
 * @since 07/2016: Adaptiert für TMC-Meldungen durch: BitCtrl Systems GmbH
 * @author BitCtrl Systems GmbH, Gieseler
 */
public class LokalerStoerfall extends Stoerfall {
	/**
	 * Instanziiert einen lokalen Störfall für einen Messquerschnitt.
	 * 
	 * @param mq
	 *            der Messquerschnitt, für den der lokale Störfall instanziiert
	 *            werden soll
	 * 
	 * @param stoerfallSituation
	 *            {@link StoerfallSituation}
	 */
	public LokalerStoerfall(final MessQuerschnitt mq, final StoerfallSituation stoerfallSituation) {
		super(mq, stoerfallSituation);
	}

	@Override
	protected MessQuerschnitt getObjekt() {
		return (MessQuerschnitt) super.getObjekt();
	}

	/**
	 * @return den Startoffset in m auf dem Straßensegment dieses Störfalls
	 */
	long getStartOffset() {
		/*
		 * Die Richtung des RDS-Ereignisses ist gegen die Fahrtrichtung. Deshalb
		 * wird der Parameter RDSLSIAusdehnungNach tur Berechnung des
		 * StartOffsets benutzt
		 */
		long result = getObjekt().getOffset() - (getParameter().getRDSLSIAusdehnungNach(getDavObjekt()));
		result = result < 0 ? 0 : result;
		result = result > getSegment().getLaenge() ? getSegment().getLaenge() : result;
		return result;
	}

	/**
	 * @return den Endoffset in m auf dem Straßensegment dieses Störfalls
	 */
	long getEndOffset() {
		/*
		 * Die Richtung des RDS-Ereignisses ist gegen die Fahrtrichtung. Deshalb
		 * wird der Parameter RDSLSIAusdehnungNach tur Berechnung des
		 * StartOffsets benutzt
		 */
		long result = getObjekt().getOffset() + (getParameter().getRDSLSIAusdehnungVor(getDavObjekt()));
		result = result < 0 ? 0 : result;
		result = result > getSegment().getLaenge() ? getSegment().getLaenge() : result;
		return result;
	}
}
